~ chicken-core (chicken-5) b4bfcea1aeaf2558815e1f2ee11b2476cd16e1d4


commit b4bfcea1aeaf2558815e1f2ee11b2476cd16e1d4
Author:     Evan Hanson <evhan@foldling.org>
AuthorDate: Thu Jul 12 10:53:54 2018 +1200
Commit:     Evan Hanson <evhan@foldling.org>
CommitDate: Thu Jul 12 10:53:54 2018 +1200

    Update bootstrap script to 5.0.0pre8

diff --git a/scripts/bootstrap.sh b/scripts/bootstrap.sh
index 3b80af94..0adbc2b9 100755
--- a/scripts/bootstrap.sh
+++ b/scripts/bootstrap.sh
@@ -2,27 +2,27 @@
 
 set -e
 
 # build 5.0.0pre7 development snapshot
 
-mkdir -p boot/pre7
+mkdir -p boot/pre8
 cd boot
-wget http://code.call-cc.org/dev-snapshots/2018/04/29/chicken-5.0.0pre7.tar.gz
-tar -xzf chicken-5.0.0pre7.tar.gz
-cd chicken-5.0.0pre7
-make "$@" PREFIX="$(pwd)"/../pre7
-make "$@" PREFIX="$(pwd)"/../pre7 install
+wget http://code.call-cc.org/dev-snapshots/2018/07/12/chicken-5.0.0pre8.tar.gz
+tar -xzf chicken-5.0.0pre8.tar.gz
+cd chicken-5.0.0pre8
+make "$@" PREFIX="$(pwd)"/../pre8
+make "$@" PREFIX="$(pwd)"/../pre8 install
 cd ../..
 
 # build a boot-chicken from git head using pre7 chicken and
 # then use that to build the real thing
 
 make "$@" spotless
-make "$@" CHICKEN="$(pwd)"/boot/pre7/bin/chicken boot-chicken
+make "$@" CHICKEN="$(pwd)"/boot/pre8/bin/chicken boot-chicken
 
-# remove pre7 installation and tarball
-rm -fr boot/pre7
-rm -fr boot/chicken-5.0.0pre7
-rm -f  boot/chicken-5.0.0pre7.tar.gz
+# remove pre8 installation and tarball
+rm -fr boot/pre8
+rm -fr boot/chicken-5.0.0pre8
+rm -f  boot/chicken-5.0.0pre8.tar.gz
 
 echo
 echo 'Now, build chicken by passing "CHICKEN=./chicken-boot" to make,'
@@ -2,27 +2,27 @@
 set -e
 
-# build 5.0.0pre7 development snapshot
+# build 5.0.0pre8 development snapshot
 
@@ -2,27 +2,27 @@
 cd ../..
 
-# build a boot-chicken from git head using pre7 chicken and
+# build a boot-chicken from git head using pre8 chicken and
 # then use that to build the real thing
 
Trap